"""
    A module for randomly applying uppercase to strings.

    To use it simply use the function random_caps(string, chance),
    string being the string to randomly apply uppercase and chance
    being the chance of applying uppercase to a letter.

    Example:
        random_cap("random", 100)
        Each letter would have a 1 in 100 chance of turning uppercase
"""
